@@ -16,7 +16,7 @@ pub enum AttributeValue {
 }
 
 impl AttributeValue {
-    pub fn from_ipp(bytes: &Vec<u8>, offset: usize, value_tag: ValueTag) -> (usize, Self) {
+    pub fn from_ipp(bytes: &[u8], offset: usize, value_tag: ValueTag) -> (usize, Self) {
         let len: usize;
         let value: Self;
         match value_tag {
